@@ -37,5 +37,18 @@ async fn single_transient_interface() {
     
     let dependency = root_context.resolve::<Box<dyn GetStr>>().await.unwrap();
 
+    assert_eq!(dependency.get(), "test".to_string());
+}
+
+#[test]
+fn single_transient_interface_sync() {
+    use crate::{DependencyContext, DependencyLifeCycle};
+
+    let root_context = DependencyContext::new_root();
+    root_context.register_type_sync::<TransientDependency>(DependencyLifeCycle::Transient).unwrap()
+        .map_as_sync::<dyn GetStr>().unwrap();
+    
+    let dependency = root_context.resolve_sync::<Box<dyn GetStr>>().unwrap();
+
     assert_eq!(dependency.get(), "test".to_string());
 }
\ No newline at end of file
